
Further Readings
================

* Must-read for everyone into the automotive measurement and calibration business:

    `XCP - Das Stndardprotokoll für die Steuergeräte-Entwicklung (Dipl.-Ing. Andreas Patzer, Dipl.-Ing. Rainer Zaiser. Vector Informatik GmbH, Stuttgart 2016) <https://assets.vector.com/cms/content/application-areas/ecu-calibration/xcp/XCP_ReferenceBook_V3.0_DE.pdf>`_

    `XCP -The Standard Protocol for ECU Development (Dipl.-Ing. Andreas Patzer, Dipl.-Ing. Rainer Zaiser. Vector Informatik GmbH, Stuttgart 2016) <https://assets.vector.com/cms/content/application-areas/ecu-calibration/xcp/XCP_ReferenceBook_V3.0_EN.pdf>`_

* `MSR-SW: <http://www.msr-wg.de/>`_ The mother of many automotive related XML formats (including `Autosar <https://autosar.org>`_ XML).
  Meet legends like ADMIN-DATA, COMPU-METHOD, and SHORT-NAME.


`MSR Engineering Documentation (MEDOC) MSRSW.DTD Elements and attributes <http://www.msr-wg.de/medoc/download/msrsw/v110/msrsw_v10/msrsw_v110-eadoc-en/msrsw-eadoc-en.pdf>`_

* Ever wondered how to implement interpolation and table lookup functions?
    `Specification of Fixed Point Interpolation Routines <https://www.autosar.org/fileadmin/user_upload/standards/classic/4-2/AUTOSAR_SWS_IFXLibrary.pdf>`_
